@@ -22,12 +22,12 @@
 
 #define EXTRAICONPATH ""
 
-#define ROOT__cplusplus 201703L
+#define ROOT__cplusplus 202302L
 #if defined(__cplusplus) && (__cplusplus != ROOT__cplusplus)
 # if defined(_MSC_VER)
-#  pragma message("The C++ standard in this build does not match ROOT configuration (201703L); this might cause unexpected issues. And please make sure you are using the -Zc:__cplusplus compilation flag")
+#  pragma message("The C++ standard in this build does not match ROOT configuration (202302L); this might cause unexpected issues. And please make sure you are using the -Zc:__cplusplus compilation flag")
 # else
-#  warning "The C++ standard in this build does not match ROOT configuration (201703L); this might cause unexpected issues"
+#  warning "The C++ standard in this build does not match ROOT configuration (202302L); this might cause unexpected issues"
 # endif
 #endif
 
@@ -36,7 +36,7 @@
 #define R__HAS_PTHREAD    /**/
 #undef R__HAS_XFT    /**/
 #define R__HAS_COCOA    /**/
-#define R__HAS_VC    /**/
+#undef R__HAS_VC    /**/
 #define R__HAS_VDT    /**/
 #define R__HAS_VECCORE    /**/
 #define R__USE_CXXMODULES   /**/
@@ -47,7 +47,7 @@
 #define R__USE_IMT   /**/
 #undef R__COMPLETE_MEM_TERMINATION /**/
 #undef R__HAS_CEFWEB  /**/
-#undef R__HAS_QT5WEB  /**/
+#undef R__HAS_QT6WEB  /**/
 #define R__HAS_DAVIX  /**/
 #define R__HAS_DATAFRAME /**/
 #define R__HAS_ROOT7 /**/
